@@ -22,7 +22,6 @@
 # include "options.h"
 # include "insn-constants.h"
 # include "config/h8300/h8300.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/gnu-user.h"
 # include "config/linux.h"
@@ -36,8 +35,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
